@@ -87,14 +87,14 @@ def rich_func(func, *args, **kwargs) -> Any:
     console = kwargs.pop("console") if "console" in kwargs else Console()
     pbar = kwargs.pop("progress") if "progress" in kwargs else apply_progress_theme(theme=theme, console=console)
     with pbar:
-        task_id = pbar.add_task(f"Running {func.__name__}", total=1)
+        task_id = pbar.add_task(f"Running {func.__name__}", total=None)
         try:
             result = func(*args, **kwargs)
-            pbar.update(task_id, advance=1)
+            pbar.update(task_id, advance=100)
         except Exception as e:
             pbar.console.print(f"[bold red]Error while running {func.__name__}[/bold red]")
             pbar.console.print(e)
-            pbar.update(task_id, advance=1)
+            pbar.update(task_id, advance=100)
             raise e
     return result
     
@@ -158,7 +158,7 @@ def rich_func_chainer(
                     result = f(*args, **params[i], **kwargs)
                 else:
                     result = f(params[i], *args, **kwargs)
-                    
+
                 progress.update(task_id, advance=1)
             except Exception as e:
                 progress.console.print(f"[bold red]Error while running {f.__name__}[/bold red]")
